pub enum MinifyError {
NotUtf8,
Css(String),
Js(String),
Io(Error),
}Expand description
Why minify could not produce output for the given bytes.
Variants
NotUtf8
The bytes were not valid UTF-8 (both minifiers work on text, not arbitrary bytes).
Css(String)
The CSS minifier rejected the input.
Js(String)
The JS minifier rejected the input.
Io(Error)
Reading the source file failed while minifying it on demand.