pub enum SpaTransition {
Fade,
Slide,
}Expand description
How spa-mode animates the swap between pages, set via
crate::Server::with_spa_transition. Both variants use the View
Transitions API when the browser supports it, and are a plain synchronous
swap (no animation) otherwise.
Variants
Fade
The browser’s default cross-fade, with no CSS injected. This is the
default for with_spa_mode()/with_spa_root() when
with_spa_transition() isn’t called.
Slide
The outgoing page slides out to the left while the incoming page
slides in from the right — the same direction for every navigation,
including the browser Back button. mini-static injects the CSS this
needs (keyframes, and the mix-blend-mode: normal override the
browser’s default cross-fade blend mode requires to look like a clean
slide instead of a wash between the two pages) — no site CSS required.